pub struct LangbaseClient { /* private fields */ }Expand description
Client for interacting with Langbase Pipes API
Implementations
Sourceimpl LangbaseClient
impl LangbaseClient
Sourcepub fn new(
config: &LangbaseConfig,
request_config: RequestConfig,
) -> LangbaseResult<Self>
pub fn new( config: &LangbaseConfig, request_config: RequestConfig, ) -> LangbaseResult<Self>
Create a new Langbase client
Sourcepub async fn call_pipe(
&self,
request: PipeRequest,
) -> LangbaseResult<PipeResponse>
pub async fn call_pipe( &self, request: PipeRequest, ) -> LangbaseResult<PipeResponse>
Call a Langbase pipe with the given request
Sourcepub async fn create_pipe(
&self,
request: CreatePipeRequest,
) -> LangbaseResult<CreatePipeResponse>
pub async fn create_pipe( &self, request: CreatePipeRequest, ) -> LangbaseResult<CreatePipeResponse>
Create a new pipe
Sourcepub async fn delete_pipe(
&self,
owner_login: &str,
pipe_name: &str,
) -> LangbaseResult<()>
pub async fn delete_pipe( &self, owner_login: &str, pipe_name: &str, ) -> LangbaseResult<()>
Delete a pipe by name (uses beta endpoint)
Sourcepub async fn ensure_linear_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
pub async fn ensure_linear_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
Ensure the linear reasoning pipe exists, creating it if needed
Sourcepub async fn ensure_tree_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
pub async fn ensure_tree_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
Ensure the tree reasoning pipe exists, creating it if needed
Sourcepub async fn ensure_divergent_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
pub async fn ensure_divergent_pipe(&self, pipe_name: &str) -> LangbaseResult<()>
Ensure the divergent reasoning pipe exists, creating it if needed
Sourcepub async fn ensure_reflection_pipe(
&self,
pipe_name: &str,
) -> LangbaseResult<()>
pub async fn ensure_reflection_pipe( &self, pipe_name: &str, ) -> LangbaseResult<()>
Ensure the reflection reasoning pipe exists, creating it if needed
Sourcepub async fn ensure_all_pipes(&self) -> LangbaseResult<()>
pub async fn ensure_all_pipes(&self) -> LangbaseResult<()>
Ensure all reasoning pipes exist, creating them if needed
Sourcepub async fn ensure_auto_router_pipe(&self) -> LangbaseResult<()>
pub async fn ensure_auto_router_pipe(&self) -> LangbaseResult<()>
Ensure the auto mode router pipe exists
Sourcepub async fn ensure_consolidated_detection_pipe(
&self,
pipe_name: &str,
) -> LangbaseResult<()>
pub async fn ensure_consolidated_detection_pipe( &self, pipe_name: &str, ) -> LangbaseResult<()>
Ensure the consolidated detection pipe exists (prompts passed dynamically)
Sourcepub async fn ensure_consolidated_got_pipe(
&self,
pipe_name: &str,
) -> LangbaseResult<()>
pub async fn ensure_consolidated_got_pipe( &self, pipe_name: &str, ) -> LangbaseResult<()>
Ensure the consolidated GoT pipe exists (prompts passed dynamically)
Sourcepub async fn ensure_detection_pipes(&self) -> LangbaseResult<()>
pub async fn ensure_detection_pipes(&self) -> LangbaseResult<()>
Ensure detection pipe exists
Sourcepub async fn ensure_got_pipes(&self) -> LangbaseResult<()>
pub async fn ensure_got_pipes(&self) -> LangbaseResult<()>
Ensure GoT pipes exist
Sourcepub async fn ensure_consolidated_decision_framework_pipe(
&self,
pipe_name: &str,
) -> LangbaseResult<()>
pub async fn ensure_consolidated_decision_framework_pipe( &self, pipe_name: &str, ) -> LangbaseResult<()>
Ensure the consolidated decision framework pipe exists (prompts passed dynamically)
Sourcepub async fn ensure_decision_framework_pipes(&self) -> LangbaseResult<()>
pub async fn ensure_decision_framework_pipes(&self) -> LangbaseResult<()>
Ensure all decision framework pipes exist, creating them if needed