pub struct AppState {Show 15 fields
pub config: Config,
pub storage: SqliteStorage,
pub langbase: LangbaseClient,
pub linear_mode: LinearMode,
pub tree_mode: TreeMode,
pub divergent_mode: DivergentMode,
pub reflection_mode: ReflectionMode,
pub backtracking_mode: BacktrackingMode,
pub auto_mode: AutoMode,
pub got_mode: GotMode,
pub decision_mode: DecisionMode,
pub evidence_mode: EvidenceMode,
pub detection_mode: DetectionMode,
pub preset_registry: Arc<PresetRegistry>,
pub self_improvement: Option<Arc<SelfImprovementSystem>>,
}Expand description
Application state shared across handlers.
Contains all mode handlers and shared resources needed for processing reasoning requests.
Fields
config: ConfigApplication configuration.
storage: SqliteStorageSQLite storage backend.
langbase: LangbaseClientLangbase API client.
linear_mode: LinearModeLinear reasoning mode handler.
tree_mode: TreeModeTree reasoning mode handler.
divergent_mode: DivergentModeDivergent reasoning mode handler.
reflection_mode: ReflectionModeReflection reasoning mode handler.
backtracking_mode: BacktrackingModeBacktracking mode handler.
auto_mode: AutoModeAuto mode router handler.
got_mode: GotModeGraph-of-Thoughts mode handler.
decision_mode: DecisionModeDecision framework mode handler.
evidence_mode: EvidenceModeEvidence assessment mode handler.
detection_mode: DetectionModeDetection mode handler for bias/fallacy detection.
preset_registry: Arc<PresetRegistry>Workflow preset registry.
self_improvement: Option<Arc<SelfImprovementSystem>>Self-improvement system (optional, enabled via config).
When enabled, monitors system health and can take autonomous actions to improve performance, error rates, and quality.
Implementations
Sourceimpl AppState
impl AppState
Sourcepub fn new(
config: Config,
storage: SqliteStorage,
langbase: LangbaseClient,
) -> Self
pub fn new( config: Config, storage: SqliteStorage, langbase: LangbaseClient, ) -> Self
Create new application state
Sourcepub async fn record_invocation(&self, event: InvocationEvent)
pub async fn record_invocation(&self, event: InvocationEvent)
Record an invocation event for self-improvement monitoring.
This should be called after each tool invocation to feed metrics to the self-improvement system.
Sourcepub fn self_improvement_enabled(&self) -> bool
pub fn self_improvement_enabled(&self) -> bool
Check if self-improvement system is enabled.